@@ -15,6 +15,7 @@
  */
 package org.owasp.esapi.http;
 
+import javax.servlet.ReadListener;
 import javax.servlet.ServletInputStream;
 import java.io.IOException;
 
@@ -28,6 +29,7 @@ public class MockServletInputStream extends ServletInputStream {
 
     private int next;
 
+    private boolean isDone = false;
     /**
      * constructor
      * @param body
@@ -45,7 +47,23 @@ public class MockServletInputStream extends ServletInputStream {
         if (next < body.length) {
             return body[next++];
         } else {
+        	isDone = true;
             return -1;
         }
     }
+
+	@Override
+	public boolean isFinished() {
+		return isDone;
+	}
+
+	@Override
+	public boolean isReady() {
+		return false;
+	}
+
+	@Override
+	public void setReadListener(ReadListener readListener) {
+		//NO_OP
+	}
 }
